library(mosaic)
library(ppcor)
library(psych)
library(MASS)
library(ggplot2)
library(arm)
#Data for Test 1 -------
#Association between slug's shell-drilling behaviour, and adult snail's shell tuba and ribs intensity. 
holes <- read.csv("C:/Liew Thor Seng/PhD thesis/Predation/manuscript/File S2. Raw data and R script for data analysis for all experiments 09092013/Experiment 1(b).csv")
str(holes)
summary(holes)

between_or_on_spine <- holes[,5]
between0_or_on_spine1 <- 1-holes[,5]
hole_width <- holes[,4]
spine_number <- holes[,3]
ribs_spacing_larger_than_hole <- holes[,6]
ribs_spacing_smaller_than_hole <- spine_number - ribs_spacing_larger_than_hole
probability_ribs_spacing_larger_than_hole <- (ribs_spacing_larger_than_hole/spine_number)
odds_ribs_spacing_larger_than_hole <- (ribs_spacing_larger_than_hole/ribs_spacing_smaller_than_hole )
probability_ribs_spacing_smaller_than_hole <- ribs_spacing_smaller_than_hole/spine_number

hole_width_on_spine <- holes[64:133,4]
hole_width_between_spine <- holes[1:63,4]
spine_number_on_spine <- holes[64:133,3]
spine_number_between_spine <- holes[1:63,3]
ribs_spacing_larger_than_hole_on_spine <- holes[64:133,6]
ribs_spacing_larger_than_hole_between_spine <- holes[1:63,6]
probability_ribs_spacing_larger_than_hole_on_spine <- probability_ribs_spacing_larger_than_hole[64:133]
probability_ribs_spacing_larger_than_hole_between_spine <- probability_ribs_spacing_larger_than_hole[1:63]

#Analysis for test 1(a)-------------
##expected probablity of the hole between spines and observed probablity of the hole between spines
cat_spine_number6<- cut(spine_number, breaks = c(40,60,80,100,120,140,160),  labels = c(1:6))
Ccat_spine_number6<-  c(1,2,3,4,5,6)
table6cat <- table(cat_spine_number6,between_or_on_spine)
empirical_prop_hole_between_ribs6 <- c((table6cat[7]/(table6cat[7]+table6cat[1])),(table6cat[8]/(table6cat[8]+table6cat[2])),(table6cat[9]/(table6cat[9]+table6cat[3])),(table6cat[10]/(table6cat[10]+table6cat[4])),(table6cat[11]/(table6cat[11]+table6cat[5])),(table6cat[12]/(table6cat[12]+table6cat[6])))
boxplot(probability_ribs_spacing_larger_than_hole~cat_spine_number6, col = c("grey"),ylim=c(0,1),xaxt="n")
labels<-c("40-60(n=35)","60-80(n=20)","80-100(n=23)","100-120(n=31)","120-140(n=22)","140-160(n=2)", tck=0.5,las=1)
par(cex.axis=0.5)
axis(1, labels=c(labels), at=1:8, las=1,)
points(Ccat_spine_number6,empirical_prop_hole_between_ribs6,col="red", pch=8, cex=2)

#Logistic regression
par(mfrow=c(2,2))
#Logistic regression model
glm.out_HW_SN_C = glm(between_or_on_spine ~ hole_width + spine_number + ribs_spacing_larger_than_hole, family=binomial(logit))
#AIC: 83.352, IC,SN
summary(glm.out_HW_SN_C)

SN <- seq((min(spine_number)),(max(spine_number)),5.5)
HW <- seq((min(hole_width)),(max(hole_width)),0.0105)
C <- seq((min(ribs_spacing_larger_than_hole)),(max(ribs_spacing_larger_than_hole)),3.8)#0.042
coeff_of_model_HW_SN_C <- glm.out_HW_SN_C$coefficients 
BS_HW_SN_C <- exp(coeff_of_model_HW_SN_C[1] + coeff_of_model_HW_SN_C[3]*SN)/(1+(exp(coeff_of_model_HW_SN_C[1] + coeff_of_model_HW_SN_C[3]*SN)))


plot(between_or_on_spine~spine_number,pch=4,ylim=c(0,1), yaxt="n")
axis(2, at=seq(0, 1, by=1) , labels= seq(0, 1, by=1)) 
lines(SN,BS_HW_SN_C,col="blue",lwd=2)

plot(between_or_on_spine~hole_width,pch=4,ylim=c(0,1), yaxt="n")
axis(2, at=seq(0, 1, by=1) , labels= seq(0, 1, by=1)) 
lines(HW,BS_HW_SN_C,col="blue",lwd=2)

plot(between_or_on_spine~ribs_spacing_larger_than_hole,pch=4,ylim=c(0,1), yaxt="n")
axis(2, at=seq(0, 1, by=1) , labels= seq(0, 1, by=1)) 
lines(C,BS_HW_SN_C,col="blue",lwd=2)

# Data for Experiment 1 (b) & 1 (c)------
A <- read.csv("C:/Liew Thor Seng/PhD thesis/Predation/manuscript/File S2. Raw data and R script for data analysis for all experiments 09092013/Experiment 1(c) and 1(d).csv")
Total_shell_material <- A[,2]
ratio <- A[,3]
spine <- A[,4]
Shell_only_material <- A[,5]
Spine_only_material <- A[,6]
thickness <- A[,7]
whorls <- A[,8] 
height <- A[,9]	
width <- A[,10]
residue_spine_volume_after_controlling_for_shell_volume <- A[,11]
residue_spine_number_after_controlling_for_shell_volume <- A[,12]
residue_thickness_after_controlling_for_shell_volume <- A[,13]

shapiro.test(Shell_only_material)
shapiro.test(Spine_only_material)
shapiro.test(ratio)
shapiro.test(spine)
shapiro.test(thickness)
shapiro.test(whorls)
shapiro.test(height) 
shapiro.test(width)

#Analysis for Experiment 1 (b)------ 
#Correlation between ribs density and ribs intensity and shell size of Plectostoma shell.
correlation_analysis_1<- cor.test(Spine_only_material,spine, method='pearson')
correlation_analysis_1
correlation_analysis_2<- cor.test(Spine_only_material,Shell_only_material, method='pearson')
correlation_analysis_2
correlation_analysis_3<- cor.test(spine,Shell_only_material, method='pearson')
correlation_analysis_3

#Partial Correlation between ribs density and ribs intensity after controlling for shell size.
library(ppcor)
pcor.test(Spine_only_material,spine,Shell_only_material,method='pearson')


#Analysis Experiment 1 (c)------
#Correlation between ribs density and shell thickness and shell size of Plectostoma shell.
correlation_analysis_4<- cor.test(thickness,spine, method='pearson')
correlation_analysis_4
correlation_analysis_5<- cor.test(thickness,Shell_only_material, method='pearson')
correlation_analysis_5
correlation_analysis_6<- cor.test(spine,Shell_only_material, method='pearson')
correlation_analysis_6

#Partial Correlation between ribs density and shell thickness after controlling for shell size.
library(ppcor)
pcor.test(thickness,spine,Shell_only_material,method='pearson')


#Data and analysis for Experiment 2 (b)------
#Association between slug's shell- apertural entry behaviour, snail anti-predatory behaviour
par(mfrow=c(3,1))
library(MASS)
hole_position_dataset <- read.csv("C:/Liew Thor Seng/PhD thesis/Predation/manuscript/File S2. Raw data and R script for data analysis for all experiments 09092013/Experiment 2(b).csv")
hole_position <- hole_position_dataset[,9]
hole_side <- hole_position_dataset[,10] 
number_of_ribs <-hole_position_dataset[,3]
hole_size <- hole_position_dataset[,4]

hole_position.freq <- table(hole_position)
hole_side.freq <- table(hole_side)

barplot(hole_position.freq,col=c("white","lightgrey","black","white","lightgrey","darkgrey","black","white","lightgrey","darkgrey","black","white"))
boxplot(number_of_ribs~hole_position)
boxplot(hole_size~hole_position)

barplot(hole_side.freq,col=c("black","white","lightgrey","darkgrey"))
boxplot(number_of_ribs~hole_side)

chisq.test(c(47,46,24,16))
kruskal.test(hole_size~hole_side)
kruskal.test(number_of_ribs~hole_side)

